<?php

namespace Drupal\paragraphs_frontend_ui\Form;

use Drupal\Component\Utility\NestedArray;
use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

class SettingsForm extends ConfigFormBase {

  public const SETTINGS_NAME = 'paragraphs_frontend_ui.settings';

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'paragraphs_frontend_ui';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      self::SETTINGS_NAME,
    ];
  }

  /**
   * {@inheritdoc}
   *
   * This form should reflect the fields in the zone content type from the
   * police_zones module. Settings will be stored localy in a config storage,
   * but will also be synched to the central storage.
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config(self::SETTINGS_NAME);

    $form['enable_nested_paragraphs'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Enable nested paragraphs fix'),
      '#default_value' => $config->get('enable_nested_paragraphs'),
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    parent::submitForm($form, $form_state);

    $this->config(self::SETTINGS_NAME)
      ->set('enable_nested_paragraphs', $form_state->getValue('enable_nested_paragraphs'))
      ->save();
  }

}
